@@ -20,9 +20,8 @@ from plone.memoize.instance import memoize
 
 
 INFO_TPL = \
-u"""Locker %(lockerid)d was successfully reserved for %(fullname)s (%(username)s).
-This locker is only available to master students. If you are not a master student,
-please visit the. FUI office for manual registration."""
+u"""Locker %(lockerid)d was successfully reserved for
+%(fullname)s (%(username)s)."""
 
 
 
